@@ -139,9 +139,7 @@ class LambdaToElasticSearchAndKibana(
         id: str,
         *,
         domain_name: str,
-        es_domain_props: typing.Optional[
-            aws_cdk.aws_elasticsearch.CfnDomainProps
-        ] = None,
+        es_domain_props: typing.Optional[aws_cdk.aws_elasticsearch.CfnDomainProps] = None,
         existing_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function] = None,
         lambda_function_props: typing.Optional[aws_cdk.aws_lambda.FunctionProps] = None,
     ) -> None:
@@ -220,9 +218,7 @@ class LambdaToElasticSearchAndKibanaProps:
         self,
         *,
         domain_name: str,
-        es_domain_props: typing.Optional[
-            aws_cdk.aws_elasticsearch.CfnDomainProps
-        ] = None,
+        es_domain_props: typing.Optional[aws_cdk.aws_elasticsearch.CfnDomainProps] = None,
         existing_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function] = None,
         lambda_function_props: typing.Optional[aws_cdk.aws_lambda.FunctionProps] = None,
     ) -> None:
@@ -236,13 +232,9 @@ class LambdaToElasticSearchAndKibanaProps:
         :summary:: The properties for the CognitoToApiGatewayToLambda Construct
         """
         if isinstance(es_domain_props, dict):
-            es_domain_props = aws_cdk.aws_elasticsearch.CfnDomainProps(
-                **es_domain_props
-            )
+            es_domain_props = aws_cdk.aws_elasticsearch.CfnDomainProps(**es_domain_props)
         if isinstance(lambda_function_props, dict):
-            lambda_function_props = aws_cdk.aws_lambda.FunctionProps(
-                **lambda_function_props
-            )
+            lambda_function_props = aws_cdk.aws_lambda.FunctionProps(**lambda_function_props)
         self._values = {
             "domain_name": domain_name,
         }
